@@ -1,7 +1,7 @@
 __version__ = "0.1.0"
 
 from .crawler import run_spider, run_all_spiders, run_spider_sync, run_all_spiders_sync, cleanup_loop
-from .utils import load_settings_with_path, init_logger, run_coroutine_in_thread, run_coroutine_in_new_loop, ProcessTaskManager
+from .utils import load_settings_with_path, init_logger
 
 __all__ = [
     "run_spider",
