@@ -1,10 +1,11 @@
 from .fetch import Downloader
-from .internet import Request, HttpRequest, WebSocketRequest, Response, HttpResponse, WebSocketResponse
+from .internet import Request, HttpRequest, MediaRequest, WebSocketRequest, Response, HttpResponse, WebSocketResponse
 
 __all__ = [
     "Downloader",
     "Request",
     "HttpRequest",
+    "MediaRequest",
     "WebSocketRequest",
     "Response",
     "HttpResponse",
