@@ -9,12 +9,31 @@ import asyncio, hashlib, random
 from curl_cffi import requests
 from tenacity import AsyncRetrying, stop_after_attempt, wait_fixed, retry_if_exception_type
 from typing import Union, Dict, Set, TYPE_CHECKING, Literal, Optional, List
+from .downloader.internet import MediaRequest
 from ..utils import create_uniqueId, run_with_timeout
 if TYPE_CHECKING:
     from logging import Logger
     from ..crawler import Crawler
-    from ..models.api import SettingsInfo
+    from ..settings import SettingsInfo
+    from curl_cffi.requests import Response
     from .downloader.internet import HttpRequest, WebSocketRequest
+    from ..mq.kafka import KafkaManager
+
+class CloseSignal:
+    def __init__(
+        self, 
+        session_id: str, 
+        websocket_end_for_key: Union[str, Literal[False], None]=False, 
+        websocket_end_for_url: Union[str, Literal[False], None]=False, 
+        session_end=False
+    ):
+        self.session_id = session_id
+        self.websocket_end_for_key = websocket_end_for_key
+        self.websocket_end_for_url = websocket_end_for_url
+        self.session_end = session_end
+
+    def __repr__(self):
+        return f"<CloseSignal session_id={self.session_id} ws_end={self.websocket_end_for_url} sess_end={self.session_end}>"
 
 class WebSocketEntry:
     """
@@ -162,14 +181,19 @@ class SessionWrapper:
     Wraps an asynchronous HTTP session (curl_cffi.requests.AsyncSession) and maintains a WebSocketPool for that session.
     Supports configuring session-level cookies, retry policy, performing HTTP and WebSocket requests with retries, and closing connections.
     """
-    def __init__(self, settings: "SettingsInfo"=None, cookies: Dict=None):
+    def __init__(self, stop_event: asyncio.Event, settings: "SettingsInfo"=None, cookies: Dict=None, kafkaManager: "KafkaManager" = None):
+        self.stop_event = stop_event
         self.settings = settings
         from ..utils import init_logger
         self.logger = init_logger(log_info=self.settings.LOG_INFO, logger_name=__name__)
+        if kafkaManager:
+            from ..utils import KafkaLoggingHandler
+            kafka_handler = KafkaLoggingHandler(kafka=kafkaManager, stop_event=self.stop_event).create_fmt(self.settings)
+            self.logger.addHandler(kafka_handler)
 
         self.session = requests.AsyncSession()
         self.websocket_pool: WebSocketPool = WebSocketPool(logger=self.logger)
-        self.default_cookies = cookies or {}
+        self.default_cookies = cookies or self.settings.DEFAULT_COOKIES
         self.update_session_cookies(self.default_cookies)
         self._lock = asyncio.Lock()
 
@@ -208,8 +232,38 @@ class SessionWrapper:
                     return await self.ws_connect_once(session, request)
                 else:
                     return await self.do_request_once(session, request)
+                
+    async def media_req(self, session: requests.AsyncSession, request: MediaRequest):
+        all_file_data = []
+        part_byte_start = 0
+        part_byte_end = request.single_part_size
+        single_part_response = None
+        while not self.stop_event.is_set():
+            if request.media_size < part_byte_end: # The size of the last segment = total file size - the starting index of the next segment to obtain the file bytes
+                part_byte_end = request.media_size - part_byte_start
+            else:
+                part_byte_end = part_byte_start + request.single_part_size
+            
+            range_key = request.find_header_key("Range")
+            range_key = range_key if range_key else "Range"
+            request.headers[range_key] = f"bytes={part_byte_start}-{part_byte_end}"
+            single_part_response: "Response" = await session.request(
+                method=request.method, 
+                **self._build_request_args(request)
+            )
+            single_part_data = single_part_response.content
+            all_file_data.append(single_part_data)
+            part_byte_start = part_byte_end + 1
+            if part_byte_start >= request.media_size:
+                media_data = b''.join(all_file_data)
+                single_part_response.content = media_data
+                break
+        return single_part_response
     
     async def do_request_once(self, session: requests.AsyncSession, request: "HttpRequest"):
+        if isinstance(request, MediaRequest):
+            return await self.media_req(session=session, request=request)
+        
         method: Literal["GET", "POST", "PUT", "DELETE", "OPTIONS", "HEAD", "TRACE", "PATCH"] = request.method
         raw_response = await session.request(
             method=method,
@@ -220,7 +274,7 @@ class SessionWrapper:
     async def ws_connect_once(self, session: requests.AsyncSession, request: "WebSocketRequest"):
         websocket: "requests.websockets.WebSocket" = await session.ws_connect(url=request.url, 
             headers=request.headers, 
-            cookies=request.cookies if request.cookies else session.cookies.get_dict(), 
+            cookies=session.cookies.get_dict(), 
             proxies=request.proxies, 
             timeout=request.timeout,
             allow_redirects=request.allow_redirects,
@@ -264,13 +318,14 @@ class SessionManager:
     Tracks reference counts for each session to manage usage, marks sessions as ended when tasks complete, and queues sessions for safe asynchronous cleanup via a background reaper loop.
     Provides methods to get/create sessions, batch register sessions with cookies, acquire/release sessions references, mark sessions as ended, and close sessions/groups safely without concurrency issues.
     """
-    def __init__(self, stop_event=None, settings=None):
+    def __init__(self, stop_event=None, settings=None, kafkaManager=None):
         self._default_session_id = create_uniqueId()
         self._sessions: Dict[str, SessionWrapper] = {self._default_session_id: None}
         self._group_sessions: Dict[str, List[str]] = {}
 
         self.stop_event: asyncio.Event = stop_event
         self.settings: "SettingsInfo" = settings
+        self.kafkaManager: "KafkaManager" = kafkaManager
 
         # Tracks the current reference count (usage) for each session_id. Format: {session_id: count}
         self._ref_counts: Dict[str, int] = {} 
@@ -287,12 +342,17 @@ class SessionManager:
         self._pending_close_set: Set[str] = set()
         from ..utils import init_logger
         self.logger = init_logger(log_info=self.settings.LOG_INFO, logger_name=__name__)
+        if self.kafkaManager:
+            from ..utils import KafkaLoggingHandler
+            kafka_handler = KafkaLoggingHandler(kafka=self.kafkaManager, stop_event=self.stop_event).create_fmt(self.settings)
+            self.logger.addHandler(kafka_handler)
 
     @classmethod
     def from_crawler(cls, crawler: "Crawler"):
         return cls(
             stop_event=crawler.stop_event, 
             settings=crawler.settings,
+            kafkaManager=crawler.kafkaManager,
         )
 
     def debug_sessions(self):
@@ -317,9 +377,11 @@ class SessionManager:
 
         wrapper = self._sessions.get(session_id)
         if wrapper:
+            if cookies:
+                wrapper.update_session_cookies(cookies)
             return wrapper
 
-        wrapper = SessionWrapper(settings=self.settings, cookies=cookies)
+        wrapper = SessionWrapper(stop_event=self.stop_event, settings=self.settings, cookies=cookies, kafkaManager=self.kafkaManager)
         self._sessions[session_id] = wrapper
         return wrapper
     
@@ -332,7 +394,7 @@ class SessionManager:
 
         for session_id, cookies in user_cookies.items():
             if session_id not in self._sessions:
-                wrapper = SessionWrapper(settings=self.settings, cookies=cookies)
+                wrapper = SessionWrapper(stop_event=self.stop_event, settings=self.settings, cookies=cookies, kafkaManager=self.kafkaManager)
                 self._sessions[session_id] = wrapper
                 session_ids.append(session_id)
             else:
@@ -422,11 +484,19 @@ class SessionManager:
             await wrapper.websocket_pool.close_all()
             await wrapper.session_close()
 
-    async def session_end_cookies(self, session_id: str) -> Union[Dict, None]:
-        wrapper = self._sessions.get(session_id)
-        if wrapper:
-            ret_cookies = {session_id: wrapper.session.cookies.get_dict()}
-            return ret_cookies
+    def get_session_cookies(self, session_id: str) -> Union[Dict, None]:
+        ret_cookies = {}
+        if session_id in self._group_sessions:
+            session_ids = self._group_sessions[session_id]
+            for it in session_ids:
+                wrapper = self._sessions.get(it)
+                if wrapper:
+                    ret_cookies[it] = wrapper.session.cookies.get_dict()
+        else:
+            wrapper = self._sessions.get(session_id)
+            if wrapper:
+                ret_cookies = {session_id: wrapper.session.cookies.get_dict()}
+        return ret_cookies
 
     async def close_all(self) -> None:
         await asyncio.gather(*[self._safe_close(session_id) for session_id in list(self._sessions.keys())])
