@@ -3,13 +3,12 @@ from .core.api import *
 from .interceptors import ChainManager, InterruptibleChainManager
 # from .interceptors import DownloadInterceptor
 from .interceptors.api import UpdateRequestSpiderInterceptor, RobotSpiderInterceptor
-from .pipelines.api import _InnerPipeline
+from .pipelines import Pipeline
 from .extensions import SignalManager
-from .utils import load_object, get_class_name, get_all_spiders_cls, get_all_spiders_name, RobotsManager, get_run_py_dir
-from contextlib import asynccontextmanager
+from .utils import load_object, get_class_name, get_all_spiders_cls, get_all_spiders_name, RobotsManager, get_run_py_dir, async_context_factory, KafkaLoggingHandler
 from typing import TYPE_CHECKING
 if TYPE_CHECKING:
-    from .models.api import SettingsInfo
+    from .settings import SettingsInfo
     from logging import Logger
 if sys.platform.startswith("win"):
     asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
@@ -29,7 +28,13 @@ class Crawler:
         self.pipelines_chain = None
         self.sessions = None
         self.sessions_lock = None
+
         self.redisManager = None
+        self.mysqlManager = None
+        self.mongodbManager = None
+        self.rabbitmqManager = None
+        self.kafkaManager = None
+
         self.logger: "Logger" = None
         self.signalManager = None
         self.robot = None
@@ -38,11 +43,6 @@ class Crawler:
         self.spiders = None
         self.engines = None
 
-    @staticmethod
-    @asynccontextmanager
-    async def empty_global_context():
-        yield
-
     def init_output(self, class_list):
         return [get_class_name(it) for it in class_list] if isinstance(class_list, list) else [get_class_name(class_list)]
 
@@ -50,20 +50,31 @@ class Crawler:
         self.stop_event = asyncio.Event()
 
         self.settings: "SettingsInfo" = settings
-        if self.settings.MAX_GLOBAL_CONCURRENT_TASKS:
-            global_sem = asyncio.BoundedSemaphore(self.settings.MAX_GLOBAL_CONCURRENT_TASKS)
-            @asynccontextmanager
-            async def global_sem_context():
-                async with global_sem:
-                    yield
-            self.global_lock = global_sem_context
-        else:
-            self.global_lock = self.empty_global_context
+        from .cpy import CExtensionLoader
+        from .models.api import CPYExtension
+
+        framework_cpy = [
+            CPYExtension(module_name="bloom")
+        ]
+        framework_cpy.extend(self.settings.CPY_EXTENSIONS.RESOURCES) # User first principle, same name can cover framework modules
+        self.settings.CPY_EXTENSIONS.RESOURCES = framework_cpy
+        CExtensionLoader(resource_dir=self.settings.CPY_EXTENSIONS.DIR).load_all(configs=self.settings.CPY_EXTENSIONS.RESOURCES)
+
+        self.global_lock = async_context_factory(
+            max_tasks=self.settings.MAX_GLOBAL_CONCURRENT_TASKS,
+            semaphore_cls=asyncio.BoundedSemaphore
+        )
 
         # if not logger: # To ensure log stability, it is no longer enabled
         from .utils import init_logger
         logger = init_logger(log_info=self.settings.LOG_INFO, logger_name=__name__)
         self.logger = logger
+        # kafka
+        if self.settings.KAFKA_INFO.resolved_url:
+            from .mq.kafka import KafkaManager
+            self.kafkaManager = KafkaManager.from_crawler(self)
+            kafka_handler = KafkaLoggingHandler(kafka=self.kafkaManager, stop_event=self.stop_event).create_fmt(self.settings)
+            self.logger.addHandler(kafka_handler)
 
         self.sessions_lock = asyncio.Lock()
         self.sessions = SessionManager.from_crawler(self)
@@ -71,30 +82,53 @@ class Crawler:
         self.robot = RobotsManager.from_crawler(self)
         
         # redis
-        if self.settings.REDIS_INFO.REDIS_URL:
+        if self.settings.REDIS_INFO.resolved_url:
             from .databases import RedisManager
             self.redisManager = RedisManager.from_crawler(self)
 
+        # mysql
+        if self.settings.MYSQL_INFO.resolved_url:
+            from .databases.mysql import SQLAlchemyMySQLManager
+            self.mysqlManager = SQLAlchemyMySQLManager.from_crawler(self)
+
+        # mongodb
+        if self.settings.MONBODB_INFO.resolved_url:
+            from .databases.mongodb import MongoDBManager
+            self.mongodbManager = MongoDBManager.from_crawler(self)
+
+        # rabbitmq
+        if self.settings.RABBITMQ_INFO.resolved_url:
+            from .mq.rabbitmq import RabbitMQManager
+            self.rabbitmqManager = RabbitMQManager.from_crawler(self)
+            if not self.settings.SCHEDULER:
+                self.settings.SCHEDULER = "scrapy_cffi.scheduler.RabbitMqScheduler"
+
         self.settings.SPIDER_INTERCEPTORS_PATH.value.extend([RobotSpiderInterceptor, UpdateRequestSpiderInterceptor])
         self.spiderInterceptor_chain = InterruptibleChainManager.from_crawler(self, class_list=self.settings.SPIDER_INTERCEPTORS_PATH.value)
 
         # self.settings.DOWNLOAD_INTERCEPTORS_PATH.value.insert(0, DownloadInterceptor)
         self.downloadInterceptor_chain = InterruptibleChainManager.from_crawler(self, class_list=self.settings.DOWNLOAD_INTERCEPTORS_PATH.value)
 
-        self.settings.ITEM_PIPELINES_PATH.value.insert(0, _InnerPipeline)
+        self.settings.ITEM_PIPELINES_PATH.value.insert(0, Pipeline)
         self.pipelines_chain = ChainManager.from_crawler(self, class_list=self.settings.ITEM_PIPELINES_PATH.value)
 
         from .hooks import signals_hooks
         for ext_cls in self.settings.EXTENSIONS_PATH.value:
-            self.extensions_list.append(ext_cls.from_crawler(signals_hooks(self)))
+            self.extensions_list.append(ext_cls.from_crawler(
+                hooks=signals_hooks(self), 
+                redisManager=self.redisManager,
+                mysqlManager=self.mysqlManager,
+                mongodbManager=self.mongodbManager,
+                rabbitmqManager=self.rabbitmqManager,
+                kafkaManager=self.kafkaManager,
+        ))
 
         self.downloader = Downloader.from_crawler(self)
 
         # spider start type
         if not self.settings.SPIDERS_PATH:
             self.settings.SPIDERS_PATH = str(self.run_py_dir / "spiders")
-            import warnings
-            warnings.warn(f"not provided self.settings.SPIDERS_PATH，guessed to load -> {self.settings.SPIDERS_PATH}")
+            self.logger.warning(f"not provided self.settings.SPIDERS_PATH，guessed to load -> {self.settings.SPIDERS_PATH}")
             start_type = 0
         if start_type:
             self.spiders = [load_object(path=self.settings.SPIDERS_PATH)]
@@ -171,9 +205,15 @@ class Crawler:
             for spider in self.spiders:
                 if getattr(spider, "redis_key", None):
                     await self.redisManager.delete(spider.redis_key)
-            await self.redisManager.delete(self.settings.PROJECT_NAME)
-            await self.redisManager.delete(self.settings._FILTER_NEW_SEEN_REQ_KEY)
-            await self.redisManager.delete(self.settings._FILTER_IS_REQ_KEY)
+            await self.redisManager.delete(self.settings.QUEUE_NAME)
+            await self.redisManager.delete(self.settings._NEW_SEEN)
+            await self.redisManager.delete(self.settings._SENT_SEEN)
+        
+        if self.rabbitmqManager:
+            await self.rabbitmqManager.close()
+
+        if self.kafkaManager:
+            await self.kafkaManager.close()
 
         # await asyncio.sleep(1)
         for engine in self.engines:
@@ -192,31 +232,18 @@ def cleanup_loop(loop: asyncio.AbstractEventLoop):
     loop.close()
 
 # One spider corresponds to one engine
-# Run a single spider, where one set of components corresponds to one spider
-async def run_spider(settings: "SettingsInfo", new_loop=False, *args, **kwargs):
+async def run_base(start_type, settings: "SettingsInfo", new_loop=False, *args, **kwargs):
     if new_loop: # Suitable for running in an independent thread or synchronous start, use with caution to avoid cross event loop operations
         now_loop = asyncio.new_event_loop()
         asyncio.set_event_loop(now_loop)
     else: # Suitable for calling within an existing asynchronous environment (default)
         now_loop = asyncio.get_running_loop()
     crawler = Crawler()
-    robot_task = await crawler.do_initialization(settings=settings, start_type=1)
+    robot_task = await crawler.do_initialization(settings=settings, start_type=start_type)
     engine_task = now_loop.create_task(crawler.start_engines(robot_task=robot_task, *args, **kwargs))
     return crawler, engine_task
 
-# Run all spiders, where one set of components corresponds to multiple spiders
-async def run_all_spiders(settings: "SettingsInfo", new_loop=False, *args, **kwargs):
-    if new_loop:
-        now_loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(now_loop)
-    else:
-        now_loop = asyncio.get_running_loop()
-    crawler = Crawler()
-    robot_task = await crawler.do_initialization(settings=settings, start_type=0)
-    engine_task = now_loop.create_task(crawler.start_engines(robot_task=robot_task, *args, **kwargs))
-    return crawler, engine_task
-
-def run_spider_sync(settings: "SettingsInfo", new_loop=True, *args, **kwargs):
+def run_sync_base(start_type, settings: "SettingsInfo", new_loop=True, *args, **kwargs):
     if new_loop:
         loop = asyncio.new_event_loop()
         asyncio.set_event_loop(loop)
@@ -227,7 +254,7 @@ def run_spider_sync(settings: "SettingsInfo", new_loop=True, *args, **kwargs):
     async def main():
         nonlocal crawler
         crawler = Crawler()
-        robot_task = await crawler.do_initialization(settings=settings, start_type=1)
+        robot_task = await crawler.do_initialization(settings=settings, start_type=start_type)
         await crawler.start_engines(robot_task, *args, **kwargs)
         crawler.stop_event.set()
         # await asyncio.Event().wait()
@@ -254,38 +281,25 @@ def run_spider_sync(settings: "SettingsInfo", new_loop=True, *args, **kwargs):
     finally:
         cleanup_loop(loop=loop)
 
+# Run a single spider, where one set of components corresponds to one spider
+async def run_spider(settings: "SettingsInfo", new_loop=False, *args, **kwargs):
+    return await run_base(start_type=1, settings=settings, new_loop=new_loop, *args, **kwargs)
+
+# Run all spiders, where one set of components corresponds to multiple spiders
+async def run_all_spiders(settings: "SettingsInfo", new_loop=False, *args, **kwargs):
+    return await run_base(start_type=0, settings=settings, new_loop=new_loop, *args, **kwargs)
+
+def run_spider_sync(settings: "SettingsInfo", new_loop=True, *args, **kwargs):
+    return run_sync_base(start_type=1, settings=settings, new_loop=new_loop, *args, **kwargs)
+
 def run_all_spiders_sync(settings: "SettingsInfo", new_loop=True, *args, **kwargs):
-    if new_loop:
-        loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(loop)
-    else:
-        loop = asyncio.get_running_loop()
-    crawler: Crawler = None
+    return run_sync_base(start_type=0, settings=settings, new_loop=new_loop, *args, **kwargs)
 
-    async def main():
-        nonlocal crawler
-        crawler = Crawler()
-        robot_task = await crawler.do_initialization(settings=settings, start_type=0)
-        await crawler.start_engines(robot_task, *args, **kwargs)
-        crawler.stop_event.set()
-        # await asyncio.Event().wait()
-        await crawler.shutdown()
-
-    if sys.platform != "win32":
-        import signal
-        def handler():
-            loop.stop()
-        try:
-            loop.add_signal_handler(signal.SIGINT, handler)
-            loop.add_signal_handler(signal.SIGTERM, handler)
-        except NotImplementedError:
-            pass
-
-    try:
-        loop.run_until_complete(main())
-    except KeyboardInterrupt:
-        print("KeyboardInterrupt detected, shutting down...")
-        if crawler:
-            loop.run_until_complete(crawler.shutdown())
-    finally:
-        cleanup_loop(loop=loop)
\ No newline at end of file
+__all__ = [
+    "Crawler",
+    "cleanup_loop",
+    "run_spider",
+    "run_all_spiders",
+    "run_spider_sync",
+    "run_all_spiders_sync",
+]
\ No newline at end of file
